@@ -37,7 +37,7 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         Sends a message from the attached emitter device
         :param emitter_devices: The emitter devices to send the message
         :param msg: The message to send
-        :return: None
+        :return: Time required to send the message
         """
         total_time = 0
         probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
@@ -60,7 +60,7 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         """
         Receive messages on the receiver device
         :param receiver_devices: The receiver device name as a string
-        :return: None
+        :return: The list of messages and the time required to receive them
         """
         total_time = 0
         messages = []
@@ -95,6 +95,21 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             f_led.set(led_on)
             led_on = not led_on
 
+    def get_processing_energy(self):
+        probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
+        probe_cpu_time = self.probe.get_metric('ProcessCpuTimeMetric')
+        probe_io_time = self.probe.get_metric('ProcessIOTimeMetric')
+
+        cpu_time = probe_cpu_time.get_val()
+        flight_time = probe_alive_time.get_val()
+        t = probe_io_time.get_val()
+        io_time = 0 if t is None else t
+
+        return self.energy_model.processing_energy.calculate(cpu_time_active=cpu_time, flight_time=flight_time, io_time=io_time)
+
+    def get_communication_energy(self, comm_emmition_time, comm_receival_time):
+        return self.energy_model.communication_energy.calculate(transmit_time=comm_emmition_time, receive_time=comm_receival_time, idle_time=0)
+
     def run(self):
         # Wait a second before starting
         while self.step(self.basic_time_step) != -1:
@@ -112,12 +127,10 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             if self.devices[device_name]['type'] == EnableableDevice.RECEIVER:
                 receiver_devices.append(device_name)
 
-        probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
-        probe_cpu_time = self.probe.get_metric('ProcessCpuTimeMetric')
-        probe_io_time = self.probe.get_metric('ProcessIOTimeMetric')
-
         total_energy = 0
         net_transaction_time = 0
+        comm_emmition_time = 0
+        comm_receival_time = 0
 
         while self.step(self.basic_time_step) != -1:
             self.blink_led_lights(led_devices)
@@ -125,21 +138,20 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
             # Drone sends data specified by the user to the base station if ML is not running on board
             # TODO:
-
-            # Calculate energy values on each cycle
-            cpu_time = probe_cpu_time.get_val()
-            flight_time = probe_alive_time.get_val()
-            t = probe_io_time.get_val()
-            io_time = 0 if t is None else t
-            # idle_time = flight_time - (cpu_time + io_time)
-            # total_energy += flight_time * self.DJI_A3_FC
-            print(self.energy_model.processing_energy.calculate(cpu_time_active=cpu_time, flight_time=flight_time, io_time=io_time))
+            comm_emmition_time += self.send_msg(msg="test", emitter_devices=emitter_devices)
+            received_messages, receival_time = self.receive_msgs(receiver_devices=receiver_devices)
+            comm_receival_time += receival_time
 
             # Execute prediction pipeline step
-            # if self.model is not None:
-            #     prediction = self.model.predict()
-            #     if prediction is not None:
-            #         print(prediction)
+            if self.model is not None:
+                prediction = self.model.predict()
+                if prediction is not None:
+                    print(prediction)
+
+            # Get energy values on each cycle
+            print(self.get_processing_energy())
+            print(self.get_communication_energy(comm_emmition_time=comm_emmition_time, comm_receival_time=comm_receival_time))
+
 
 
 class AutopilotMavic2DJI(AutopilotControlledDrone):
